/*----------------------------------------------------------------------
  File    : gmutil.h
  Contents: utility functions for inducing graphical models
  Author  : Christian Borgelt
  History : 2006.03.04 file created
            2006.03.10 log file added to structure GMID
            2007.01.29 field GMID.inicnt added
----------------------------------------------------------------------*/
#ifndef __GMUTIL__
#define __GMUTIL__
#ifndef GM_EVAL
#define GM_EVAL
#endif
#ifndef GM_INDUCE
#define GM_INDUCE
#endif
#include "gramod.h"

/*----------------------------------------------------------------------
  Type Definitions
----------------------------------------------------------------------*/
typedef struct {                /* --- edge --- */
  ATTID  x, y;                  /* connected nodes, coordinates */
  int    mark;                  /* marker (> 0: edge is selectable) */
  int    dir;                   /* direction (for function _extst) */
  double eval;                  /* evaluation result */
} GMEDGE;                       /* (edge) */

typedef struct {                /* --- induction data --- */
  GRAMOD *gm;                   /* graphical model */
  TABLE  *table;                /* table to induce model from */
  int    search;                /* search method */
  int    measure;               /* evaluation measure */
  double params[2];             /* evaluation measure parameters */
  double thresh;                /* threshold (e.g. for improvement) */
  double mrgimp;                /* minimum imp. for leaf merging */
  int    lwise;                 /* flag for levelwise leaf merging */
  ATTID  maxcon;                /* maximum number of conditions */
  ATTID  ptmax;                 /* maximum number of trees */
  ATTID  attcnt;                /* number of attributes */
  ATTID  inicnt;                /* number of initial   edges */
  ATTID  potcnt;                /* number of potential edges */
  ATTID  selcnt;                /* number of selected  edges */
  GMEDGE **etab;                /* edge (evaluation) table */
  GMEDGE **edges;               /* selected edges (for _owst()) */
  ATTID  *adjs;                 /* identifiers of adjacent nodes */
  void   *citrie;               /* conditional independence trie */
  FILE   *log;                  /* log file for evaluation output */
} GMID;                         /* (graphical model induction data) */

/*----------------------------------------------------------------------
The edge table is an n x n matrix (n: number of attributes) in which
each entry corresponds to the edge defined by the column index x and
the row index y. An edge is directed y -> x. To avoid confusion, the
connected nodes are also called x and y in the edge structure.
----------------------------------------------------------------------*/

/*----------------------------------------------------------------------
  Functions
----------------------------------------------------------------------*/
extern int   gmu_init    (GMID *gmid, ATTID cnt, int half);
extern ATTID gmu_edges   (GMID *gmid);
extern int   gmu_eval    (GMID *gmid, ATTID cnt, int dep);
extern ATTID gmu_filter  (GMID *gmid);
extern ATTID gmu_span    (GMID *gmid);
extern void  gmu_cleanup (GMID *gmid);
extern int   gmu_cmp     (const void *p1, const void *p2, void *data);
extern int   gmu_ptaggr  (PTREE **trees, ATTID n, TABLE *table);
extern int   gmu_ptclean (PTREE **trees, ATTID n, void *p);

#endif
