#-----------------------------------------------------------------------
# File    : ines.mak
# Contents: commands to network induction programs
# Author  : Christian Borgelt
# History : 2003.01.27 file created
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\ines\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src
TABLEDIR = ..\..\table\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATHDIR) /I $(TABLEDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_1   = $(UTILDIR)\fntypes.h    $(UTILDIR)\scanner.h    \
           $(TABLEDIR)\attset.h
HDRS_2   = $(HDRS_1)               $(UTILDIR)\tabread.h    \
           $(UTILDIR)\error.h
HDRS_3   = $(HDRS_2)               $(TABLEDIR)\table.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\random.obj   \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\attset3.obj ptree1.obj
INES_O   = $(OBJS)                 $(UTILDIR)\memsys.obj   \
           $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2rw.obj  \
           $(TABLEDIR)\table3.obj  $(MATHDIR)\gamma.obj    \
           ptree2.obj ptree3.obj ptree4.obj ptree5.obj     \
           graphx.obj citrie.obj hyper.obj gmutil.obj gm_pars.obj \
           gramod2.obj gramod3.obj gramod4.obj gramod5.obj ines.obj
GENDB_O  = $(OBJS) ptree2.obj gm_pars.obj gendb.obj
NEVAL_O  = $(OBJS) $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2rw.obj \
           $(TABLEDIR)\table3.obj ptree2.obj gm_pars.obj neval.obj
CONDEP_O = $(OBJS) $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2ro.obj \
           ptree2.obj ptree3.obj condep.obj
GRAPH_O  = $(UTILDIR)\scanner.obj gramain.obj
HYPER_O  = $(UTILDIR)\arrays.obj $(UTILDIR)\random.obj hypmain.obj
CITRIE_O = $(UTILDIR)\arrays.obj $(UTILDIR)\memsys.obj citmain.obj
PRGS     = ines.exe gendb.exe neval.exe condep.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

ines.exe:     $(INES_O) ines.mak
	$(LD) $(LDFLAGS) $(INES_O) $(LIBS) /out:$@

gendb.exe:    $(GENDB_O) ines.mak
	$(LD) $(LDFLAGS) $(GENDB_O) $(LIBS) /out:$@

neval.exe:    $(NEVAL_O) ines.mak
	$(LD) $(LDFLAGS) $(NEVAL_O) $(LIBS) /out:$@

condep.exe:   $(CONDEP_O) ines.mak
	$(LD) $(LDFLAGS) $(CONDEP_O) $(LIBS) /out:$@

graph.exe:    $(GRAPH_O) ines.mak
	$(LD) $(LDFLAGS) $(GRAPH_O) $(LIBS) /out:$@

hyper.exe:    $(HYPER_O) ines.mak
	$(LD) $(LDFLAGS) $(HYPER_O) $(LIBS) /out:$@

citrie.exe:   $(CITRIE_O) ines.mak
	$(LD) $(LDFLAGS) $(CITRIE_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
ines.obj:     $(HDRS_3) $(UTILDIR)\random.h ptree.h gramod.h
ines.obj:     ines.c ines.mak
	$(CC) $(CFLAGS) $(INCS) ines.c /Fo$@

gendb.obj:    $(HDRS_2)             $(UTILDIR)\random.h \
              $(UTILDIR)\tabwrite.h gramod.h ptree.h
gendb.obj:    gendb.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gendb.c /Fo$@

neval.obj:    $(HDRS_3) ptree.h gramod.h
neval.obj:    neval.c ines.mak
	$(CC) $(CFLAGS) $(INCS) neval.c /Fo$@

condep.obj:   $(HDRS_3) ptree.h
condep.obj:   condep.c ines.mak
	$(CC) $(CFLAGS) $(INCS) condep.c /Fo$@

gramain.obj:  $(UTILDIR)\scanner.h  $(UTILDIR)\error.h
gramain.obj:  graph.h graph.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D GR_PARSE /D GR_MAIN graph.c /Fo$@

hypmain.obj:  $(UTILDIR)\fntypes.h  $(UTILDIR)\arrays.h \
              $(UTILDIR)\random.h
hypmain.obj:  hyper.h hyper.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D HYP_MAIN hyper.c /Fo$@

citmain.obj:  $(UTILDIR)\fntypes.h  $(UTILDIR)\arrays.h \
              $(UTILDIR)\memsys.h
citmain.obj:  citrie.h citrie.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D CIT_MAIN citrie.c /Fo$@

#-----------------------------------------------------------------------
# Probability/Possibility Tree Management
#-----------------------------------------------------------------------
ptree1.obj:   $(HDRS_1)
ptree1.obj:   ptree.h ptree1.c ines.mak
	$(CC) $(CFLAGS) $(INCS) ptree1.c /Fo$@

ptree2.obj:   $(HDRS_1) $(UTILDIR)\scanner.h
ptree2.obj:   ptree.h ptree2.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D PT_PARSE ptree2.c /Fo$@

ptree3.obj:   $(HDRS_1) $(UTILDIR)\arrays.h
ptree3.obj:   ptree.h ptree3.c ines.mak
	$(CC) $(CFLAGS) $(INCS) ptree3.c /Fo$@

ptree4.obj:   $(HDRS_1) $(MATHDIR)\gamma.h
ptree4.obj:   ptree.h ptree4.c ines.mak
	$(CC) $(CFLAGS) $(INCS) ptree4.c /Fo$@

ptree5.obj:   $(HDRS_1) $(MATHDIR)\gamma.h
ptree5.obj:   ptree.h ptree5.c ines.mak
	$(CC) $(CFLAGS) $(INCS) ptree5.c /Fo$@

#-----------------------------------------------------------------------
# Graph and Hypertree Management
#-----------------------------------------------------------------------
graph.obj:    $(UTILDIR)\error.h
graph.obj:    graph.h graph.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D GR_PARSE graph.c /Fo$@

graphp.obj:   $(UTILDIR)\scanner.h  $(UTILDIR)\error.h
graphp.obj:   graph.h graph.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D GR_PARSE graph.c /Fo$@

graphx.obj:   $(UTILDIR)\scanner.h  $(UTILDIR)\error.h \
              $(TABLEDIR)\attset.h
graphx.obj:   graph.h graph.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D GR_EXTFN graph.c /Fo$@

hyper.obj:    $(UTILDIR)\fntypes.h  $(UTILDIR)\arrays.h
hyper.obj:    hyper.h $(UTILDIR)\arrays.h hyper.c ines.mak
	$(CC) $(CFLAGS) $(INCS) hyper.c /Fo$@

#-----------------------------------------------------------------------
# Conditional Independence Trie Management
#-----------------------------------------------------------------------
citrie.obj:   $(UTILDIR)\fntypes.h  $(UTILDIR)\arrays.h \
              $(UTILDIR)\memsys.h
citrie.obj:   citrie.h citrie.c ines.mak
	$(CC) $(CFLAGS) $(INCS) citrie.c /Fo$@

#-----------------------------------------------------------------------
# Graphical Model Management
#-----------------------------------------------------------------------
gramod1.obj:  $(HDRS_1) ptree.h
gramod1.obj:  gramod.h gramod1.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gramod1.c /Fo$@

gm_pars.obj:  $(HDRS_1) ptree.h
gm_pars.obj:  gramod.h gramod1.c ines.mak
	$(CC) $(CFLAGS) $(INCS) /D GM_PARSE gramod1.c /Fo$@

gramod2.obj:  $(HDRS_1) $(TABLEDIR)\table.h ptree.h
gramod2.obj:  gramod.h gramod2.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gramod2.c /Fo$@

gramod3.obj:  $(HDRS_1) $(TABLEDIR)\table.h ptree.h
gramod3.obj:  gramod.h gramod3.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gramod3.c /Fo$@

gramod4.obj:  $(HDRS_1)             $(UTILDIR)\arrays.h \
              $(UTILDIR)\memsys.h   $(TABLEDIR)\table.h \
              ptree.h gmutil.h graph.h citrie.h
gramod4.obj:  gramod.h gramod4.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gramod4.c /Fo$@

gramod5.obj:  $(HDRS_1) $(TABLEDIR)\table.h hyper.h ptree.h
gramod5.obj:  gramod.h gramod5.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gramod5.c /Fo$@

gmutil.obj:   $(HDRS_1)             $(UTILDIR)\arrays.h \
              $(TABLEDIR)\table.h   gramod.h ptree.h
gmutil.obj:   gmutil.h gmutil.c ines.mak
	$(CC) $(CFLAGS) $(INCS) gmutil.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\memsys.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak memsys.obj
	cd $(THISDIR)
$(MATHDIR)\gamma.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak gamma.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2rw.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2rw.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\table3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table3.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f ines.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS) graph.exe
